<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace FiloBlu\Rma\Block\Returns;
use FiloBlu\Rma\Api\RmaExtensionAttributesRepositoryInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Catalog\Api\ProductRepositoryInterface;
use FiloBlu\Rma\Helper\ChangeSizeAttributeHelper;
use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Framework\Registry;
use Magento\Rma\Helper\Data;
use Magento\Framework\App\Http\Context;
use Magento\Customer\Helper\View as MagentoView;
use Magento\Customer\Helper\Session\CurrentCustomer;
use Magento\Rma\Model\Item\FormFactory;
use Magento\Rma\Model\ItemFactory;
use Magento\Rma\Model\ResourceModel\Rma\Status\History\CollectionFactory;
use Magento\Rma\Model\ResourceModel\Item\CollectionFactory as ItemCollectionFactory;
use Magento\Eav\Model\Config;
use Magento\Eav\Model\Form\Factory;
use Magento\Framework\Data\Collection\ModelFactory;
use Magento\Framework\View\Element\Template\Context as TemplateContext;

class View extends \Magento\Rma\Block\Returns\View
{

    /**
     * @var RmaExtensionAttributesRepositoryInterface
     */
    private $rmaExtensionAttributesRepository;
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;
    /**
     * @var ProductRepositoryInterface
     */
    private $productRepository;
    /**
     * @var ChangeSizeAttributeHelper
     */
    private $changeSizeAttributeHelper;


    /**
     * View constructor.
     * @param TemplateContext $context
     * @param ModelFactory $modelFactory
     * @param Factory $formFactory
     * @param Config $eavConfig
     * @param ItemCollectionFactory $itemsFactory
     * @param CollectionFactory $historiesFactory
     * @param ItemFactory $itemFactory
     * @param FormFactory $itemFormFactory
     * @param CurrentCustomer $currentCustomer
     * @param MagentoView $customerView
     * @param Context $httpContext
     * @param Data $rmaData
     * @param Registry $registry
     * @param CustomerRepositoryInterface $customerRepository
     * @param RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository
     * @param OrderRepositoryInterface $orderRepository
     * @param ProductRepositoryInterface $productRepository
     * @param ChangeSizeAttributeHelper $changeSizeAttributeHelper
     * @param array $data
     */
    public function __construct(TemplateContext $context,
                                ModelFactory $modelFactory,
                                Factory $formFactory,
                                Config $eavConfig,
                                ItemCollectionFactory $itemsFactory,
                                CollectionFactory $historiesFactory,
                                ItemFactory $itemFactory,
                                FormFactory $itemFormFactory,
                                CurrentCustomer $currentCustomer,
                                MagentoView $customerView,
                                Context $httpContext,
                                Data $rmaData,
                                Registry $registry,
                                CustomerRepositoryInterface $customerRepository,
                                RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository,
                                OrderRepositoryInterface $orderRepository,
                                ProductRepositoryInterface $productRepository,
                                ChangeSizeAttributeHelper $changeSizeAttributeHelper,
                                array $data = [])
    {
        parent::__construct($context, $modelFactory, $formFactory, $eavConfig, $itemsFactory, $historiesFactory, $itemFactory, $itemFormFactory, $currentCustomer, $customerView, $httpContext, $rmaData, $registry, $customerRepository, $data);
        $this->rmaExtensionAttributesRepository = $rmaExtensionAttributesRepository;
        $this->orderRepository = $orderRepository;
        $this->productRepository = $productRepository;
        $this->changeSizeAttributeHelper = $changeSizeAttributeHelper;
    }

    /**
     * @param $myItem
     * @return array
     */
    public function getChangeSizeItems($myItem){

        try{
            $resolution = $myItem->getResolution();
            $newSize = array_fill_keys(['label','value'],'');
            if($this->changeSizeAttributeHelper->getChangeSizeAttributeOptionId() != $resolution){
                return $newSize;
            }

            $changeSizeOrderId  = $this->rmaExtensionAttributesRepository->getChangeSizeOrderId($myItem->getEntityId());
            if($changeSizeOrderId){
                $changeSizeOrder = $this->orderRepository->get($changeSizeOrderId);
                $items = $changeSizeOrder->getItems();
                foreach ($items as $item) {
                    $product = $this->productRepository->get($item->getSku());
                    $newSize ['label'] = $item->getProduct()->getName();
                    $newSize ['value'] = $product->getResource()->getAttribute('size')->getFrontend()->getValue($product);
                }
            }
        }catch (\Exception $e){
            $this->_logger->critical($e->getMessage());
            return $newSize;
        }

        return $newSize;
    }
}
